@@ -1,6 +1,7 @@
 import logging
 import click
 from os import environ, path
+from glob import glob
 
 from vxbase import logger
 
@@ -115,33 +116,33 @@ def build_image(**kwargs):
 
 @cli.command()
 @click.option('--logpath',
-              default=path.join('.', environ.get('CI_COMMIT_REF_SLUG', ''),
-                                'ODOO_LOG',
-                                'odoo.log'),
-              help="Path where is saved odoo.log file. Env var: LOGPATH.")
+              default=environ.get('CI_COMMIT_REF_SLUG', '.'),
+              help="Path where are saved odoo.log_* files. Env var: CI_COMMIT_REF_SLUG.")
 def check_log(logpath):
     """Checks odoo log in image to analize if there are warnings
     and show them."""
     _logger.info('Check log command')
-    logpath = path.join(logpath, "odoo.log")
-    _logger.info("Odoo log path: %s", logpath)
+    logpaths = glob(path.join(logpath, "odoo.log_*"))
 
-    if not path.isfile(logpath):
+    if not logpaths:
         _logger.warning('Odoo log file was not found in path: %s', logpath)
         exit(2)
 
-    with open(logpath) as flog:
-        sucesss, log = resume_log(flog)
+    has_warnings = False
+    for logpath in logpaths:
+        _logger.info("Odoo log path: %s", logpath)
+        with open(logpath) as flog:
+            sucesss, log = resume_log(flog)
 
-    all_warnings = log.get('warnings')
-    all_warnings.extend(log.get('warnings_deprecated'))
-    all_warnings.extend(log.get('warnings_trans'))
+        all_warnings = log.get('warnings')
+        all_warnings.extend(log.get('warnings_deprecated'))
+        all_warnings.extend(log.get('warnings_trans'))
+        for warning in all_warnings:
+            _logger.warn(warning)
+        has_warnings = has_warnings or bool(all_warnings)
 
-    if not all_warnings:
+    if not has_warnings:
         exit(0)
-
-    for warning in all_warnings:
-        _logger.warn(warning)
     exit(1)
 
 
