@@ -629,7 +629,7 @@ def prepare_coverage(config):
 
 
 def save_logs(config, logs):
-    odoo_log = path.join(config.get('container_vol'), 'odoo.log')
+    odoo_log = path.join(config.get('container_vol'), 'odoo.log_%(ci_job_name)s' % config)
     _logger.info("Save log in %s cwd %s", odoo_log, getcwd())
     with open(odoo_log, "a") as fodoo_log:
         for line in logs:
@@ -693,7 +693,7 @@ def resume_log(log_lines, allow_deprecated=False):
             and 'no translation for language' not in line \
             and 'Deprecated method' not in line \
             and 'odoo.tests.runner: 0 failed, 0 error(s) of 0 tests when loading database' not in line \
-            and (' py.warnings: ' in line and '/extra_addons/' in line)  # silent py.warnings raised from odoo core
+            and (' py.warnings: ' not in line or '/extra_addons/' in line)  # silent py.warnings raised from odoo core
 
     filters = {
         'critical': critical,
